import { useContext, createContext } from 'react';
/**
 * React context which holds mapping of store names to their instances.
 * Used as the IoC container for store injection into the components
 */
export var ProstoreContext = createContext(null);
/**
 * Extracts store from the context based on the provided name,
 * or simply uses the provided instance
 *
 * @param storeOrName - store instance to be used, or store name to be injected from the context
 */
export function useContextStore(storeOrName) {
    var context = useContext(ProstoreContext);
    if (typeof storeOrName === 'string') {
        if (!context) {
            throw new Error("ProstoreContext is not provided");
        }
        var store = context[storeOrName];
        if (!store) {
            throw new Error("Store '" + storeOrName + "' is not registered in the ProstoreContext");
        }
        return store;
    }
    return storeOrName;
}
//# sourceMappingURL=ProstoreContext.js.map